@@ -7,7 +7,7 @@ import os
 #region module
 GROUND_LEVEL = int(os.environ.get('DELOG_GROUND_LEVEL', 0))
 
-FORMAT = os.environ.get('DELOG_FORMAT', '%TIME %TEXT')
+FORMAT = os.environ.get('DELOG_FORMAT', '')
 
 ENDPOINT = os.environ.get('DELOG_ENDPOINT')
 TOKEN = os.environ.get('DELOG_TOKEN')
@@ -16,8 +16,10 @@ PROJECT = os.environ.get('DELOG_PROJECT', '')
 SPACE = os.environ.get('DELOG_SPACE', '')
 
 CALL_CONTEXT = bool(os.environ.get('DELOG_CALL_CONTEXT', False))
-CODE_PROVIDER = os.environ.get("DELOG_CODE_PROVIDER", '')
+REPOSITORY_PROVIDER = os.environ.get("DELOG_REPOSITORY_PROVIDER", '')
 REPOSITORY_NAME = os.environ.get("DELOG_REPOSITORY_NAME", '')
+REPOSITORY_BRANCH = os.environ.get("DELOG_REPOSITORY_BRANCH", 'master')
+REPOSITORY_COMMIT = os.environ.get("DELOG_REPOSITORY_COMMIT", 'latest')
 REPOSITORY_BASEPATH = os.environ.get("DELOG_REPOSITORY_BASEPATH", '')
 
 
